/*
 *  File:  x-mini-quick-start-main.c
 *
 *  Program to test Atmel ATmega328P X-mini board.
 *  The on-board "user" LED (on PB5) will flash at 1Hz while the user button
 *  is pressed (PB7 == Low);  otherwise the LED will remain off.
 *
 *  Version 2.0  2021-03-06  MJB  (simplified main fn using macros)
 */

#include <avr/io.h>
#define F_CPU 16000000UL
#include <util/delay.h>

#define BUTTON_IS_PRESSED  ((PINB & (1 << 7)) == 0)
#define TURN_LED_ON()      PORTB |= (1 << 5)
#define TURN_LED_OFF()     PORTB &= ~(1 << 5)


int main(void)
{
    DDRB = (1 << 5);   // PB5 is output for LED;  PB7 is button input
    _delay_us(1);      // short delay needed after writing to DDR

    while (1)
    {
        if (BUTTON_IS_PRESSED)
        {
            TURN_LED_ON();
            _delay_ms(500);

            TURN_LED_OFF();
            _delay_ms(500);
        }
        else  TURN_LED_OFF();
    }
}

